==> 0.8.6.tar.gz: bin/downloads/resource_manager.dart <==
import 'dart:io';

import 'package:archive/archive.dart';
import 'package:http/http.dart' as http;

import '../shared/environment.dart';
import '../generated/version.dart';

final resourceManager = ResourceManager();

class ResourceManager {
  Directory get homeDirectory {
    var envVars = Platform.environment;

    if (Platform.isMacOS)
      return Directory(envVars['HOME']!);
    else if (Platform.isLinux)
      return Directory(envVars['HOME']!);
    else if (Platform.isWindows)
      return Directory(envVars['UserProfile']!);

    throw(Exception('Unsupported platform.'));
  }

  Directory get localCacheDirectory => Directory(homeDirectory.path + '/.serverpod');
  Directory get versionedDir => Directory(localCacheDirectory.path + '/$templateVersion');
  Directory get templateDirectory {
    if (productionMode)
      return Directory(versionedDir.path + '/serverpod_template');
    else
      return Directory(serverpodHome + '/templates/serverpod_templates');
  }

  String get packageDownloadUrl => 'https://storage.googleapis.com/pub-packages/packages/serverpod_templates-$templateVersion.tar.gz';

  bool get isTemplatesInstalled {
    if (!versionedDir.existsSync())
      return false;

    return templateDirectory.existsSync();
  }

  Future<void> installTemplates() async {
    print('Downloading templates for version $templateVersion');
    if (!versionedDir.existsSync())
      versionedDir.createSync(recursive: true);

    var response = await http.get(Uri.parse(packageDownloadUrl));
    var data = response.bodyBytes;

    // var outFile = File(versionedDir.path + '/serverpod_templates.tar.gz');
    // outFile.writeAsBytesSync(data);

    var unzipped = GZipDecoder().decodeBytes(data);
    var archive = TarDecoder().decodeBytes(unzipped);

    for (var file in archive) {
      final outFileName = '${templateDirectory.path}/${file.name}';
      if (file.isFile) {
        var outFile = File(outFileName);
        outFile = await outFile.create(recursive: true);
        await outFile.writeAsBytes(file.content);
      }
      else {
        await Directory(outFileName).create(recursive: true);
      }
    }
    print('Download complete.\n');
  }
}

==> 0.9.1.tar.gz: bin/downloads/resource_manager.dart <==
import 'dart:io';

import 'package:archive/archive.dart';
import 'package:http/http.dart' as http;

import '../generated/version.dart';
import '../shared/environment.dart';

final resourceManager = ResourceManager();

class ResourceManager {
  Directory get homeDirectory {
    var envVars = Platform.environment;

    if (Platform.isMacOS) {
      return Directory(envVars['HOME']!);
    } else if (Platform.isLinux) {
      return Directory(envVars['HOME']!);
    } else if (Platform.isWindows) {
      return Directory(envVars['UserProfile']!);
    }

    throw (Exception('Unsupported platform.'));
  }

  Directory get localCacheDirectory =>
      Directory(homeDirectory.path + '/.serverpod');
  Directory get versionedDir =>
      Directory(localCacheDirectory.path + '/$templateVersion');
  Directory get templateDirectory {
    if (productionMode) {
      return Directory(versionedDir.path + '/serverpod_template');
    } else {
      return Directory(serverpodHome + '/templates/serverpod_templates');
    }
  }

  String get packageDownloadUrl =>
      'https://storage.googleapis.com/pub-packages/packages/serverpod_templates-$templateVersion.tar.gz';

  bool get isTemplatesInstalled {
    if (!versionedDir.existsSync()) return false;

    return templateDirectory.existsSync();
  }

  Future<void> installTemplates() async {
    print('Downloading templates for version $templateVersion');
    if (!versionedDir.existsSync()) versionedDir.createSync(recursive: true);

    var response = await http.get(Uri.parse(packageDownloadUrl));
    var data = response.bodyBytes;

    // var outFile = File(versionedDir.path + '/serverpod_templates.tar.gz');
    // outFile.writeAsBytesSync(data);

    var unzipped = GZipDecoder().decodeBytes(data);
    var archive = TarDecoder().decodeBytes(unzipped);

    for (var file in archive) {
      var outFileName = '${templateDirectory.path}/${file.name}';
      if (file.isFile) {
        var outFile = File(outFileName);
        outFile = await outFile.create(recursive: true);
        await outFile.writeAsBytes(file.content);
      } else {
        await Directory(outFileName).create(recursive: true);
      }
    }
    print('Download complete.\n');
  }
}
